==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Form</name>
    <message>
        <source>Single</source>
        <translatorcomment>--google--
Décompose les entités textuelles en simples lettres 
Sélectionne des entités uniques
Points uniques</translatorcomment>
        <translation type="obsolete">Un seul</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Deux : verticale</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Deux : horizontale</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Trois : droite</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Trois : gauche</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Trois : au-dessus</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Trois : en dessous</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Trois : verticale</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Trois : horizontale</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quatre : égalité</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quatre : droite</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quatre : gauche</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Espacement de la grille &lt; espacement de la meta grille</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation>Quatre : égalité</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation>Quatre : gauche</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation>Quatre : droite</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation>Un seul</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation>Trois : en dessous</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation>Trois : horizontale</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation>Trois : verticale</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation>Deux : horizontale</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation>Deux : verticale</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+320"/>
        <source>Grid</source>
        <translation>Grille</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>A l&apos;entité</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Perpendiculairement</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Centre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Milieu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Intersection</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Référence</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Espacement de la grille &lt; espacement de la meta grille</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Espacement de la grille &lt; espacement de la meta grille</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Form</name>
    <message>
        <source>Single</source>
        <translatorcomment>--google--
Décompose les entités textuelles en simples lettres 
Sélectionne des entités uniques
Points uniques</translatorcomment>
        <translation type="obsolete">Un seul</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Deux : verticale</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Deux : horizontale</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Trois : droite</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Trois : gauche</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Trois : au-dessus</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Trois : en dessous</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Trois : verticale</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Trois : horizontale</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quatre : égalité</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quatre : droite</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quatre : gauche</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Espacement de la grille &lt; espacement de la meta grille</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation>Quatre : égalité</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation>Quatre : gauche</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation>Quatre : droite</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation>Un seul</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation>Trois : en dessous</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation>Trois : horizontale</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation>Trois : verticale</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation>Deux : horizontale</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation>Deux : verticale</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+252"/>
        <source>Dropped data not supported</source>
        <translation>Données insérées pas pris en charge</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Importing file: </source>
        <translation>Importation fichier: </translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Importing URL: </source>
        <translation>Importation URL: </translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="vanished">Grille</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="vanished">Fin</translation>
    </message>
    <message>
        <source>On Entity</source>
        <translation type="vanished">A l&apos;entité</translation>
    </message>
    <message>
        <source>Perpendicular</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Perpendiculairement</translation>
    </message>
    <message>
        <source>Tangential</source>
        <translation type="vanished">Tangentiel</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Centre</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="vanished">Milieu</translation>
    </message>
    <message>
        <source>Intersection</source>
        <translation type="vanished">Intersection</translation>
    </message>
    <message>
        <source>Reference</source>
        <translation type="vanished">Référence</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Espacement de la grille &lt; espacement de la meta grille</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Espacement de la grille &lt; espacement de la meta grille</translation>
    </message>
</context>
</TS>
